<?php

/*
 * LMS version 1.11.7 Bastet
 *
 *  (C) Copyright 2001-2009 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: numberplandel.php,v 1.8 2009/01/13 07:45:52 alec Exp $
 */

$id = $_GET['id'];

if($_GET['is_sure']==1 && $id)
{
	if( !$DB->GetOne('SELECT COUNT(*) FROM documents WHERE numberplanid=?', array($id)))
	{
		$DB->Execute('DELETE FROM numberplans WHERE id=?', array($id));
		$DB->Execute('DELETE FROM numberplanassignments WHERE planid=?', array($id));
	}
}	

$SESSION->redirect('?'.$SESSION->get('backto'));

?>
